import { Component } from '@angular/core';
import { enableRipple, setCulture, loadCldr, Ajax, L10n } from '@syncfusion/ej2-base';

declare var window: Window & { culture: string };
//enable ripple style
enableRipple(true);
// Assign windoe variable culture.
window.culture = 'fr';
// assign the culture to application globally.
setCulture(window.culture);

@Component({
  selector: 'my-app',
  template: `  <div>Switch culture: </div>
  <ejs-dropdownlist id='culture' [dataSource]=cultureData (change)='onChange($event)' width='100px' [value]=value [fields]=fields></ejs-dropdownlist>
      <h1> Date Picker component </h1>
      <ejs-datepicker id="date" width="275px"></ejs-datepicker>`
})
export class AppComponent {
  public cultureData: Object[] = [
    { Id: 'fr', country: 'French' },
    { Id: 'de', country: 'German' },
    { Id: 'en-US', country: 'English' },
    { Id: 'zh', country: 'Chinese' },
    { Id: 'es', country: 'Spanish' },
];
// variable for preventing the culture files load multiple times
public loadedCultures: string[] = ['fr'];
// maps the appropriate column to fields property
public fields: Object = { text: 'country', value: 'Id' };

public waterMark: string = 'Select a Culture';
// set the value to select an item based on mapped value at initial rendering
public value: string = 'fr';
public onChange(args: any): void {
    if (this.loadedCultures.indexOf(args.value) === -1) {
        this.loadedCultures.push(args.value);
        this.loadCultureFiles(args.value);
    }

    setCulture(args.value);
}
ngOnInit(): void {
    this.loadedCultures.push(window.culture);
    this.loadCultureFiles(window.culture);
}
//Function for loading locale files based on culture name 
loadLocaleFiles(name: string) {
    // load local files
    let localeajax: Ajax = new Ajax('./node_modules/@syncfusion/ej2-locale/src/' + name + '.json', 'GET', false);
    localeajax.onSuccess = (value: string) => {
        L10n.load(JSON.parse(value));
    }
    localeajax.send();
}
// Function for loading the culture files from cldr-data.
loadCultureFiles(name: string) {
    
    this.loadLocaleFiles(name);
    // since default culture files are preloaded no need to load the files again.
    if(name === 'en-US'){
        return;
    }
    let files: string[] = ['ca-gregorian.json', 'numbers.json', 'timeZoneNames.json', 'numberingSystems.json'];

    let loadCulture = function (prop: any) {
        let val: string, ajax: Ajax;
        if (prop === files.length - 1) {
            ajax = new Ajax('./node_modules/cldr-data/supplemental/' + files[prop], 'GET', false);
        } else {
            ajax = new Ajax('./node_modules/cldr-data/main/' + name + '/' + files[prop], 'GET', false);
        }
        ajax.onSuccess = function (value: any) {
            val = value;
            loadCldr(JSON.parse(val));
        };
        ajax.send();

    };
    for (let prop = 0; prop < files.length; prop++) {
        loadCulture(prop);
    }


}
}
